--- a/tests/test-topic.t Fri Jul 07 01:01:01 2017 +0200
+++ b/tests/test-topic.t Thu Jul 06 03:56:36 2017 +0530
@@ -15,7 +15,25 @@
$ hg help topics
hg topics [TOPIC]
- View current topic, set current topic, or see all topics.
+ View current topic, set current topic, change topic for a set of revisions, or
+ see all topics.
+
+ Clear topic on existing topiced revisions:
+ 'hg topic --rev <related revset> --clear'
+
+ Change topic on some revisions:
+ 'hg topic <newtopicname> --rev <related revset>'
+
+ Clear current topic:
+ 'hg topic --clear'
+
+ Set current topic:
+ 'hg topic <topicname>'
+
+ List of topics:
+ 'hg topics'
+
+ The active topic (if any) will be prepended with a "*".
The --verbose version of this command display various information on the
state of each topic.
--- a/hgext3rd/topic/__init__.py Fri Jul 07 01:01:01 2017 +0200
+++ b/hgext3rd/topic/__init__.py Thu Jul 06 03:56:36 2017 +0530
@@ -294,7 +294,24 @@
('l', 'list', False, 'show the stack of changeset in the topic'),
] + commands.formatteropts)
def topics(ui, repo, topic='', clear=False, rev=None, list=False, **opts):
- """View current topic, set current topic, or see all topics.
+ """View current topic, set current topic, change topic for a set of revisions, or see all topics.
+
+ Clear topic on existing topiced revisions:
+ `hg topic --rev <related revset> --clear`
+
+ Change topic on some revisions:
+ `hg topic <newtopicname> --rev <related revset>`
+
+ Clear current topic:
+ `hg topic --clear`
+
+ Set current topic:
+ `hg topic <topicname>`
+
+ List of topics:
+ `hg topics`
+
+ The active topic (if any) will be prepended with a "*".
The --verbose version of this command display various information on the state of each topic."""
if list: